Stan Math Library: stan/math/prim/mat/prob Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

prob Directory Reference

## Files
file | categorical_log.hpp [code]
file | categorical_logit_log.hpp [code]
file | categorical_rng.hpp [code]
file | dirichlet_log.hpp [code]
file | dirichlet_rng.hpp [code]
file | gaussian_dlm_obs_log.hpp [code]
file | inv_wishart_log.hpp [code]
file | inv_wishart_rng.hpp [code]
file | lkj_corr_cholesky_log.hpp [code]
file | lkj_corr_cholesky_rng.hpp [code]
file | lkj_corr_log.hpp [code]
file | lkj_corr_rng.hpp [code]
file | lkj_cov_log.hpp [code]
file | matrix_normal_prec_log.hpp [code]
file | multi_gp_cholesky_log.hpp [code]
file | multi_gp_log.hpp [code]
file | multi_normal_cholesky_log.hpp [code]
file | multi_normal_cholesky_rng.hpp [code]
file | multi_normal_log.hpp [code]
file | multi_normal_prec_log.hpp [code]
file | multi_normal_rng.hpp [code]
file | multi_student_t_log.hpp [code]
file | multi_student_t_rng.hpp [code]
file | multinomial_log.hpp [code]
file | multinomial_rng.hpp [code]
file | ordered_logistic_log.hpp [code]
file | ordered_logistic_rng.hpp [code]
file | wishart_log.hpp [code]
file | wishart_rng.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.